This function implements the two-sample \(l_\infty\)-norm-based
high-dimensional mean test proposed in Cai, Liu and Xia (2014).
Suppose \(\{\mathbf{X}_1, \ldots, \mathbf{X}_{n_1}\}\) are i.i.d.
copies of \(\mathbf{X}\), and \(\{\mathbf{Y}_1, \ldots, \mathbf{Y}_{n_2}\}\)
are i.i.d. copies of \(\mathbf{Y}\).
The test statistic is defined as
$$
M_{CLX}=\frac{n_1n_2}{n_1+n_2}\max_{1\leq j\leq p}
\frac{(\bar{X_j}-\bar{Y_j})^2}
{\frac{1}{n_1+n_2} [\sum_{u=1}^{n_1} (X_{uj}-\bar{X_j})^2+\sum_{v=1}^{n_2} (Y_{vj}-\bar{Y_j})^2] }
$$
With some regularity conditions, under the null hypothesis \(H_{0c}: \mathbf{\Sigma}_1 = \mathbf{\Sigma}_2\),
the test statistic \(M_{CLX}-2\log p+\log\log p\) converges in distribution to
a Gumbel distribution \(G_{mean}(x) = \exp(-\frac{1}{\sqrt{\pi}}\exp(-\frac{x}{2}))\)
as \(n_1, n_2, p \rightarrow \infty\).
The asymptotic \(p\)-value is obtained by
$$p_{CLX} = 1-G_{mean}(M_{CLX}-2\log p+\log\log p).$$